@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for XSB 3.8.0 or later versions
-%  Last updated on February 16, 2018
+%  Last updated on April 16, 2018
 %
 %  This file is part of Logtalk <https://logtalk.org/>  
 %  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
@@ -216,6 +216,7 @@ setup_call_cleanup(Setup, Call, Cleanup) :-
 
 '$lgt_prolog_feature'(encoding_directive, unsupported).
 '$lgt_prolog_feature'(tabling, supported).
+'$lgt_prolog_feature'(engines, unsupported).
 '$lgt_prolog_feature'(threads, Threads) :-
 	(	xsb_configuration(engine_mode, 'multi-threading') ->
 		Threads = supported
@@ -247,7 +248,12 @@ setup_call_cleanup(Setup, Call, Cleanup) :-
 '$lgt_default_flag'(singleton_variables, warning).
 '$lgt_default_flag'(portability, silent).
 '$lgt_default_flag'(redefined_built_ins, silent).
+'$lgt_default_flag'(deprecated, warning).
 '$lgt_default_flag'(missing_directives, warning).
+'$lgt_default_flag'(duplicated_directives, warning).
+'$lgt_default_flag'(trivial_goal_fails, warning).
+'$lgt_default_flag'(always_true_or_false_goals, warning).
+'$lgt_default_flag'(lambda_variables, warning).
 '$lgt_default_flag'(underscore_variables, singletons).
 % optional features compilation flags:
 '$lgt_default_flag'(complements, deny).
@@ -255,7 +261,13 @@ setup_call_cleanup(Setup, Call, Cleanup) :-
 '$lgt_default_flag'(events, deny).
 '$lgt_default_flag'(context_switching_calls, allow).
 % other compilation flags:
-'$lgt_default_flag'(scratch_directory, './').
+'$lgt_default_flag'(scratch_directory, ScratchDirectory) :-
+	(	expand_atom('$COMSPEC', _) ->
+		% Windows systems define this environment variable...
+		ScratchDirectory = './lgt_tmp/'
+	;	% ... but not POSIX systems
+		ScratchDirectory = './.lgt_tmp/'
+	).
 '$lgt_default_flag'(report, on).
 '$lgt_default_flag'(clean, on).
 '$lgt_default_flag'(code_prefix, '$').
