@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for YAP Prolog 6.3.4 and later versions
-%  Last updated on December 11, 2017
+%  Last updated on April 10, 2018
 %
 %  This file is part of Logtalk <https://logtalk.org/>  
 %  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
@@ -288,6 +288,14 @@
 		Tabling = supported
 	;	Tabling = unsupported
 	).
+'$lgt_prolog_feature'(engines, Engines) :-
+	(	current_prolog_flag(system_options, threads) ->
+		Engines = supported
+	;	current_prolog_flag(system_options, Options),
+		member(threads, Options) ->
+		Engines = supported
+	;	Engines = unsupported
+	).
 '$lgt_prolog_feature'(threads, Threads) :-
 	(	current_prolog_flag(system_options, threads) ->
 		Threads = supported
@@ -322,7 +330,12 @@
 '$lgt_default_flag'(singleton_variables, warning).
 '$lgt_default_flag'(portability, silent).
 '$lgt_default_flag'(redefined_built_ins, silent).
+'$lgt_default_flag'(deprecated, warning).
 '$lgt_default_flag'(missing_directives, warning).
+'$lgt_default_flag'(duplicated_directives, warning).
+'$lgt_default_flag'(trivial_goal_fails, warning).
+'$lgt_default_flag'(always_true_or_false_goals, warning).
+'$lgt_default_flag'(lambda_variables, warning).
 '$lgt_default_flag'(underscore_variables, singletons).
 % optional features compilation flags:
 '$lgt_default_flag'(complements, deny).
