@@ -1,11 +1,11 @@
-;; logtalk.el -- font lock support for Logtalk (http://logtalk.org/)
+;; logtalk.el -- font lock support for Logtalk (https://logtalk.org/)
 
-;; Copyright (c) 2003-2014 Paulo Moura
+;; Copyright (c) 2003-2017 Paulo Moura
 
 ;; Author: Paulo Moura <pmoura@logtalk.org>
 ;; Creation date: November 15, 2003
-;; Last modification date: June 18, 2016
-;; Version: 1.31
+;; Last modification date: November 13, 2017
+;; Version: 1.34
 
 ;; Installation:
 ;;
@@ -27,7 +27,7 @@
 
 ;; setup 
 
-(defvar logtalk-mode-version "1.31"
+(defvar logtalk-mode-version "1.34"
 	"Logtalk mode version number")
 
 (defvar logtalk-mode-hook nil)
@@ -108,7 +108,7 @@
 
 (setq logtalk-font-lock-built-in-methods
 	'(
-		("\\<\\(parameter\\|se\\(?:lf\\|nder\\)\\|this\\)\\([(]\\)" 1 'logtalk-built-in-method-face)
+		("\\<\\(context\\|parameter\\|se\\(?:lf\\|nder\\)\\|this\\)\\([(]\\)" 1 'logtalk-built-in-method-face)
 		("\\<\\(current_predicate\\|predicate_property\\)\\([(]\\)" 1 'logtalk-built-in-method-face)
 		("\\<\\(a\\(?:bolish\\|ssert[az]\\)\\|clause\\|retract\\(?:all\\)?\\)\\([(]\\)" 1 'logtalk-built-in-method-face)
 		("\\<\\(bagof\\|f\\(?:\\(?:ind\\|or\\)all\\)\\|setof\\)\\([(]\\)" 1 'logtalk-built-in-method-face)
@@ -124,7 +124,7 @@
 		("\\<\\(\\(?:category\\|object\\|protocol\\)_property\\)\\([(]\\)" 1 'logtalk-built-in-predicate-face)
 		("\\<\\(co\\(?:mplements_object\\|nforms_to_protocol\\)\\|extends_\\(?:object\\|protocol\\|category\\)\\|i\\(?:mp\\(?:lements_protocol\\|orts_category\\)\\|nstantiates_class\\)\\|specializes_class\\)\\([(]\\)" 1 'logtalk-built-in-predicate-face)
 		("\\<\\(\\(?:abolish\\|define\\)_events\\|current_event\\)\\([(]\\)" 1 'logtalk-built-in-predicate-face)
-		("\\<\\(\\(?:curren\\|se\\)t_logtalk_flag\\)\\([(]\\)" 1 'logtalk-built-in-predicate-face)
+		("\\<\\(\\(?:c\\(?:reate\\|urrent\\)\\|set\\)_logtalk_flag\\)\\([(]\\)" 1 'logtalk-built-in-predicate-face)
 		("\\<\\(logtalk_\\(?:compile\\|load\\|library_path\\|load_context\\|make\\)\\)\\([(]\\)" 1 'logtalk-built-in-predicate-face)
 		("\\<logtalk_make\\>" 0 'logtalk-built-in-predicate-face)
 		("\\<\\(forall\\)\\([(]\\)" 1 'logtalk-built-in-predicate-face)
@@ -135,14 +135,12 @@
 		("\\<\\(ca\\(?:ll\\|tch\\)\\|throw\\)\\([(]\\)" 1 'logtalk-built-in-predicate-face)
 		("\\<\\(fa\\(?:il\\|lse\\)\\|true\\)\\>" 0 'logtalk-built-in-predicate-face)
 		("\\(!\\|->\\|;\\)" 0 'logtalk-built-in-predicate-face)
+		("\\<instantiation_error\\>" 0 'logtalk-built-in-predicate-face)
+		("\\<\\(\\(?:type\\|domain\\|existence\\|permission\\|representation\\|evaluation\\|resource\\)_error\\)\\([(]\\)" 1 'logtalk-built-in-predicate-face)
 		;;
 		;; multi-threading:
 		;;
-		("\\<\\(threaded\\(_\\(?:call\\|once\\|ignore\\|exit\\|peek\\|wait\\|notify\\)\\)?\\)\\([(]\\)" 1 'logtalk-built-in-predicate-face)
-		;;
-		;; engines:
-		;;
-		("\\<\\(threaded_engine\\(_\\(?:create\\|destroy\\|self\\|next\\|next_reified\\|yield\\|post\\|fetch\\)\\)?\\)\\([(]\\)" 1 'logtalk-built-in-predicate-face)
+		("\\<\\(threaded\\(?:_\\(?:call\\|e\\(?:ngine\\(?:_\\(?:create\\|destroy\\|fetch\\|next\\(?:_reified\\)?\\|post\\|self\\|yield\\)\\)?\\|xit\\)\\|ignore\\|notify\\|once\\|peek\\|wait\\)\\)?\\)" 1 'logtalk-built-in-predicate-face)
 		;;
 		;; logic and control:
 		;;
@@ -212,7 +210,7 @@
 		;;
 		;; implementation defined hooks functions:
 		;;
-		("\\<\\(\\(?:create\\|current\\|set\\)_prolog_flag\\|halt\\)\\([(]\\)" 1 'logtalk-built-in-predicate-face)
+		("\\<\\(\\(?:current\\|set\\)_prolog_flag\\|halt\\)\\([(]\\)" 1 'logtalk-built-in-predicate-face)
 		("\\<halt\\>" 0 'logtalk-built-in-predicate-face)
 		;;
 		;; atomic term processing:
@@ -253,7 +251,7 @@
 
 (setq logtalk-font-lock-numbers
 	'(
-		("\\<\\(0x[a-fA-F0-9]+\\)\\>" 1 'logtalk-number-face)
+		("\\<\\(0x[[:xdigit:]]+\\)\\>" 1 'logtalk-number-face)
 		("\\<\\(0o[0-7]+\\)\\>" 1 'logtalk-number-face)
 		("\\<\\(0b[0-1]+\\)\\>" 1 'logtalk-number-face)
 		("\\<\\(0['].\\)\\>" 1 'logtalk-number-face)
@@ -285,7 +283,9 @@
 	"Major mode for editing Logtalk files"
 	(interactive)
 	(kill-all-local-variables)
-	(setq tab-width 4)
+	(setq indent-tabs-mode t)
+	(setq tab-width (default-value 'tab-width))
+	(setq c-basic-offset (default-value 'tab-width))
 	(set-syntax-table logtalk-mode-syntax-table)
 	(set (make-local-variable 'font-lock-defaults) '(logtalk-font-lock-keywords))
 	(turn-on-font-lock)
