@@ -4,7 +4,7 @@
  * -----------
  *
  * Author: Paulo Moura (pmoura@logtalk.org)
- * Copyright: (c) 2009-2014 Paulo Moura (http://logtalk.org/)
+ * Copyright: (c) 2009-2014 Paulo Moura (https://logtalk.org/)
  * Release Version: 1.0.8.6
  * Date Started: 2009/10/24
  *
@@ -12,6 +12,10 @@
  *
  * CHANGES
  * -------
+ * 2017/11/13 (1.1.21)
+ *  -  Added syntax coloring of the error throwing built-in methods
+ * 2017/06/29 (1.1.20)
+ *  -  Added syntax coloring of the context/1 method
  * 2016/06/18 (1.1.19)
  *  -  Fixed for the rename of some of the engine predicates
  * 2016/05/29 (1.1.18)
@@ -142,7 +146,7 @@ $language_data = array(
             // event handlers
             'after', 'before', 'forward',
             // execution-context methods
-            'parameter', 'self', 'sender', 'this',
+            'context', 'parameter', 'self', 'sender', 'this',
             // predicate reflection
             'current_predicate', 'predicate_property',
             // DCGs and term expansion
@@ -168,6 +172,8 @@ $language_data = array(
             'abolish', 'asserta', 'assertz', 'clause', 'retract', 'retractall',
             // control
             'call', 'catch', 'ignore', 'once', 'throw',
+			'type_error', 'domain_error', 'existence_error', 'permission_error',
+			'representation_error', 'evaluation_error', 'resource_error'
             // all solutions predicates
             'bagof', 'findall', 'forall', 'setof',
             // multi-threading predicates
@@ -213,7 +219,7 @@ $language_data = array(
         // Built-in predicates (no arguments)
         5 => array(
             // control
-            'fail', 'false', 'repeat', 'true',
+            'fail', 'false', 'repeat', 'true', 'instantiation_error',
             // character and byte input/output predicates
             'nl',
             // implementation defined hooks functions
