@@ -1,12 +1,12 @@
-#!/bin/bash
+#!/usr/bin/env bash
 
 #############################################################################
 ## 
 ##   Unit testing automation script
-##   Last updated on September 29, 2016
+##   Last updated on March 7, 2018
 ## 
-##   This file is part of Logtalk <http://logtalk.org/>  
-##   Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
+##   This file is part of Logtalk <https://logtalk.org/>  
+##   Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
 ##   
 ##   Licensed under the Apache License, Version 2.0 (the "License");
 ##   you may not use this file except in compliance with the License.
@@ -24,16 +24,14 @@
 
 # loosely based on a unit test automation script contributed by Parker Jones
 
-export LC_ALL=C
-
 print_version() {
-	echo "$(basename "$0") 0.17"
+	echo "$(basename "$0") 0.30"
 	exit 0
 }
 
 operating_system=$(uname -s)
 
-if [ "${operating_system:0:10}" == "MINGW32_NT" ] ; then
+if [ "${operating_system:0:10}" == "MINGW32_NT" ] || [ "${operating_system:0:10}" == "MINGW64_NT" ] ; then
 	# assume that we're running on Windows using the Git for Windows bash shell
 	extension='.sh'
 elif [ "$LOGTALKHOME" != "" ] && [ "$LOGTALKUSER" != "" ] && [ "$LOGTALKHOME" == "$LOGTALKUSER" ] ; then
@@ -73,9 +71,13 @@ format_default_goal="true"
 format_tap_goal="logtalk_load(lgtunit(tap_report))"
 format_xunit_goal="logtalk_load(lgtunit(xunit_report))"
 
+coverage_default_goal="true"
+coverage_xml_goal="logtalk_load(lgtunit(coverage_report))"
+
 # default argument values
 
 base="$PWD"
+level=""
 results="$base/logtalk_tester_logs"
 backend=swipl
 prolog='SWI-Prolog'
@@ -83,36 +85,46 @@ logtalk=swilgt$extension
 logtalk_call="$logtalk -g"
 mode='normal'
 format='default'
+coverage='none'
 format_goal=$format_default_goal
+coverage_goal=$coverage_default_goal
+flag_goal="true"
+initialization_goal="true"
 # disable timeouts to maintain backward compatibility
 timeout=0
 prefix="$HOME/"
-arguments=""
+
+# use GNU sed if available instead of BSD sed
+if gsed --version >/dev/null 2>&1 ; then
+	sed="gsed"
+else
+	sed="sed"
+fi
 
 run_tests() {
 	unit=$(dirname "$1")
 	unit_short=${unit#$prefix}
-	cd "$unit"
+	cd "$unit" || exit 1
 	echo '*******************************************************************************'
 	echo "***** Testing $unit_short"
-	name=$(echo "$unit"|sed 's|/|__|g')
+	name=${unit////__}
 	if [ $mode == 'optimal' ] || [ $mode == 'all' ] ; then
-		run_test "$name" "$format_goal,$tester_optimal_goal"
+		run_test "$name" "$initialization_goal,$format_goal,$coverage_goal,$flag_goal,$tester_optimal_goal"
 		tests_exit=$?
-		grep -a 'tests:' "$results/$name.results" | sed 's/%/***** (opt)  /'
+		grep -a 'tests:' "$results/$name.results" | $sed 's/%/***** (opt)  /'
 	elif [ $mode == 'normal' ] || [ $mode == 'all' ] ; then
-		run_test "$name" "$format_goal,$tester_normal_goal"
+		run_test "$name" "$initialization_goal,$format_goal,$coverage_goal,$flag_goal,$tester_normal_goal"
 		tests_exit=$?
-		grep -a 'tests:' "$results/$name.results" | sed 's/%/*****        /'
+		grep -a 'tests:' "$results/$name.results" | $sed 's/%/*****        /'
 	elif [ $mode == 'debug' ] || [ $mode == 'all' ] ; then
-		run_test "$name" "$format_goal,$tester_debug_goal"
+		run_test "$name" "$initialization_goal,$format_goal,$coverage_goal,$flag_goal,$tester_debug_goal"
 		tests_exit=$?
-		grep -a 'tests:' "$results/$name.results" | sed 's/%/***** (debug)/'
+		grep -a 'tests:' "$results/$name.results" | $sed 's/%/***** (debug)/'
 	fi
 	if [ $tests_exit -eq 0 ] ; then
-		grep -a 'out of' "$results/$name.results" | sed 's/%/*****        /'
-		grep -a 'no code coverage information collected' "$results/$name.results" | sed 's/%/*****        /'
-		grep -a '(not applicable)' "$results/$name.results" | sed 's/(/*****         (/'
+		grep -a 'out of' "$results/$name.results" | grep -a 'clause coverage' | $sed 's/%/*****        /'
+		grep -a 'no code coverage information collected' "$results/$name.results" | $sed 's/%/*****        /'
+		grep -a '(not applicable)' "$results/$name.results" | $sed 's/(/*****         (/'
 	elif [ $tests_exit -eq 124 ] ; then
 		echo "*****         timeout"
 		echo "LOGTALK_TIMEOUT" >> "$results/$name.errors"
@@ -120,50 +132,77 @@ run_tests() {
 		echo "*****         crash"
 		echo "LOGTALK_CRASH" >> "$results/$name.errors"
 	fi
+	if [ $coverage == 'xml' ] ; then
+		if [ -d "$LOGTALKUSER" ] ; then
+			cp "$LOGTALKUSER/tools/lgtunit/coverage_report.dtd" . || true
+			cp "$LOGTALKUSER/tools/lgtunit/coverage_report.xsl" . || true
+		elif [ -d "$LOGTALKHOME" ] ; then
+			cp "$LOGTALKHOME/tools/lgtunit/coverage_report.dtd" . || true
+			cp "$LOGTALKHOME/tools/lgtunit/coverage_report.xsl" . || true
+		fi
+	fi
 	return 0
 }
 
 run_test() {
 	name="$1"
 	goal="$2"
-	if [ "$timeout_command" != "" ] && [ $timeout -ne 0 ] ; then
-		$timeout_command $timeout $logtalk_call "$goal" -- $arguments < /dev/null > "$results/$name.results" 2> "$results/$name.errors"
+	if [ ${#args[@]} -eq 0 ] ; then
+		if [ "$timeout_command" != "" ] && [ $timeout -ne 0 ] ; then
+			$timeout_command $timeout $logtalk_call "$goal" < /dev/null > "$results/$name.results" 2> "$results/$name.errors"
+		else
+			$logtalk_call "$goal" < /dev/null > "$results/$name.results" 2> "$results/$name.errors"
+		fi
 	else
-		$logtalk_call "$goal" -- $arguments < /dev/null > "$results/$name.results" 2> "$results/$name.errors"
+		if [ "$timeout_command" != "" ] && [ $timeout -ne 0 ] ; then
+			$timeout_command $timeout $logtalk_call "$goal" -- "${args[@]}" < /dev/null > "$results/$name.results" 2> "$results/$name.errors"
+		else
+			$logtalk_call "$goal" -- "${args[@]}" < /dev/null > "$results/$name.results" 2> "$results/$name.errors"
+		fi
 	fi
-	return $?
+	exit=$?
+	if [ $exit -eq 0 ] && ! grep -q "(not applicable)" "$results/$name.results" && ! grep -q "tests:" "$results/$name.results" && ! grep -q "tests skipped" "$results/$name.results"; then
+		echo "LOGTALK_BROKEN" >> "$results/$name.errors"
+	fi
+	return $exit
 }
 
 usage_help()
 {
 	echo 
-	echo "This script automates running unit tests found on the current directory and recursively"
-	echo "in its sub-directories by scanning for tester.lgt and tester.logtalk source files. In"
-	echo  "case of failed unit tests, this script returns an exit code of 1."
+	echo "This script automates running unit tests found in the current directory"
+	echo "and recursively in its sub-directories by scanning for \"tester.logtalk\""
+	echo "and \"tester.lgt\" source files.  In case of failed unit tests, timed out"
+	echo "test sets, or crashed test sets, this script returns an exit code of 1."
 	echo
 	echo "Usage:"
-	echo "  $(basename "$0") [-p prolog] [-m mode] [-f format] [-d results] [-t timeout] [-- arguments]"
+	echo "  $(basename "$0") [-p prolog] [-m mode] [-f format] [-d results] [-t timeout] [-s prefix] [-c report] [-l level] [-- arguments]"
 	echo "  $(basename "$0") -v"
 	echo "  $(basename "$0") -h"
 	echo
 	echo "Optional arguments:"
 	echo "  -v print version of $(basename "$0")"
 	echo "  -p back-end Prolog compiler (default is $backend)"
-	echo "     (possible values are b, cx, eclipse, gnu, ji, lean, qp, sicstus, swi, swipack, xsb, xsbmt, and yap)"
+	echo "     (valid values are b, cx, eclipse, gnu, ji, lean, qp, sicstus, swi, swipack, xsb, xsbmt, and yap)"
 	echo "  -m compilation mode (default is $mode)"
-	echo "     (possible values are optimal, normal, debug, and all)"
+	echo "     (valid values are optimal, normal, debug, and all)"
 	echo "  -f format for writing the test results (default is $format)"
-	echo "     (possible values are default, tap, and xunit)"
+	echo "     (valid values are default, tap, and xunit)"
 	echo "  -d directory to store the test logs (default is ./logtalk_tester_logs)"
 	echo "  -t timeout in seconds for running each test set (default is $timeout; i.e. disabled)"
-	echo "  -s supress path prefix (default is "$prefix")"
+	echo "  -s suppress path prefix (default is $prefix)"
+	echo "  -c code coverage report (default is $coverage)"
+	echo "     (valid values are none and xml)"
+	echo "  -l directory depth level to look for test sets (default is to recurse into all sub-directories)"
+	echo "     (level 1 means current directory only)"
+	echo "  -g initialization goal (default is $initialization_goal)"
 	echo "  -- arguments to be passed to the integration script used to run the tests (no default)"
 	echo "  -h help"
 	echo
 	exit 0
 }
 
-while getopts "vp:m:f:d:t:s:h" option
+while getopts "vp:m:f:d:t:s:c:l:g:h" option
 do
 	case $option in
 		v) print_version;;
@@ -173,13 +212,16 @@ do
 		d) d_arg="$OPTARG";;
 		t) t_arg="$OPTARG";;
 		s) s_arg="$OPTARG";;
+		c) c_arg="$OPTARG";;
+		l) l_arg="$OPTARG";;
+		g) g_arg="$OPTARG";;
 		h) usage_help;;
 		*) usage_help;;
 	esac
 done
 
 shift $((OPTIND - 1))
-arguments="$@"
+args=("$@")
 
 if [ "$p_arg" == "b" ] ; then
 	prolog='B-Prolog'
@@ -253,11 +295,11 @@ elif [ "$p_arg" != "" ] ; then
 	echo "Error! Unsupported back-end Prolog compiler: $p_arg"
 	usage_help
 	exit 1
-elif [ ! $(command -v $backend) ] ; then
+elif [ ! "$(command -v $backend)" ] ; then
     echo "Error! Default back-end Prolog compiler not found: $prolog"
 	usage_help
     exit 1
-elif [ ! $(command -v $logtalk) ] ; then
+elif [ ! "$(command -v $logtalk)" ] ; then
     echo "Error! $logtalk integration script for $prolog not found."
 	echo "       Check that its directory is in your execution path."
     exit 1
@@ -292,6 +334,18 @@ elif [ "$f_arg" != "" ] ; then
 	exit 1
 fi
 
+if [ "$c_arg" == "none" ] ; then
+	coverage='none'
+	coverage_goal=$coverage_default_goal
+elif [ "$c_arg" == "xml" ] ; then
+	coverage='xml'
+	coverage_goal=$coverage_xml_goal
+elif [ "$c_arg" != "" ] ; then
+	echo "Error! Unknow coverage report: $c_arg"
+	usage_help
+	exit 1
+fi
+
 if [ "$p_arg" == "swipack" ] ; then
 	versions_goal="use_module(library(logtalk)),$versions_goal"
 	format_goal="use_module(library(logtalk)),$format_goal"
@@ -309,10 +363,30 @@ if [ "$s_arg" != "" ] ; then
 	prefix="$s_arg"
 fi
 
+if [ "$l_arg" != "" ] ; then
+	if [[ "$l_arg" =~ ^[1-9][0-9]*$ ]] ; then
+		level="-maxdepth $l_arg"
+	else
+		echo "Error! Level must be an integer equal or greater than 1: $l_arg"
+		usage_help
+		exit 1
+	fi
+fi
+
+if [ "$g_arg" != "" ] ; then
+	initialization_goal="$g_arg"
+fi
+
 if [ "$timeout_command" == "" ] ; then
 	echo "Warning! Timeout support not available. The timeout option will be ignored."
 fi
 
+if [[ "$prefix" != "" && ("$format" != "default" || "$coverage" != "none") ]] ; then
+	flag_goal="set_logtalk_flag(suppress_path_prefix,'$prefix')"
+else
+	flag_goal="true"
+fi
+
 mkdir -p "$results"
 rm -f "$results"/*.results
 rm -f "$results"/*.errors
@@ -325,52 +399,62 @@ echo '**************************************************************************
 echo "***** Batch testing started @ $start_date"
 $logtalk_call $versions_goal > "$results"/tester_versions.txt 2> /dev/null
 grep -a "Logtalk version:" "$results"/tester_versions.txt
-grep -a "Prolog version:" "$results"/tester_versions.txt | sed "s/Prolog/$prolog/"
+grep -a "Prolog version:" "$results"/tester_versions.txt | $sed "s/Prolog/$prolog/"
 
 testsets=0
-output="$(find "$base" -name "tester.lgt" -or -name "tester.logtalk")"
-while read file && [ "$file" != "" ]; do
+output="$(find "$base" $level -name "tester.lgt" -or -name "tester.logtalk" | LC_ALL=C sort)"
+while read -r file && [ "$file" != "" ]; do
 	((testsets++))
 	run_tests "$file"
 done <<< "$output"
 
-cd "$results"
-timeouts=$(grep -s -a 'LOGTALK_TIMEOUT' *.errors | wc -l | sed 's/ //g')
-crashes=$(grep -s -a 'LOGTALK_CRASH' *.errors | wc -l | sed 's/ //g')
-testsetruns=$(($testsets-$timeouts-$crashes))
-skipped=$(grep -s -a ': skipped' *.results | wc -l | sed 's/ //g')
-passed=$(grep -s -a ': success' *.results | wc -l | sed 's/ //g')
-failed=$(grep -s -a ': failure' *.results | wc -l | sed 's/ //g')
-total=$(($skipped+$passed+$failed))
+cd "$results" || exit 1
+testsetskipped=$(cat -- *.results | grep -c 'tests skipped')
+timeouts=$(cat -- *.errors | grep -c 'LOGTALK_TIMEOUT')
+crashes=$(cat -- *.errors | grep -c 'LOGTALK_CRASH')
+broken=$(cat -- *.errors | grep -c 'LOGTALK_BROKEN')
+testsetruns=$((testsets-timeouts-crashes-broken))
+skipped=$(cat -- *.results | grep -c ': skipped')
+passed=$(cat -- *.results | grep -c ': success')
+failed=$(cat -- *.results | grep -c ': failure')
+total=$((skipped+passed+failed))
 
 echo "*******************************************************************************"
 echo "***** Compilation errors/warnings and failed unit tests"
 echo "***** (compilation errors/warnings might be expected depending on the test)"
 echo "*******************************************************************************"
-grep -s -a -A2 'syntax_error' *.results | sed 's/.results//' | tee errors.all
-grep -s -a -A2 'syntax_error' *.errors | sed 's/.errors//' | tee -a errors.all
-grep -s -a -h '!     ' *.errors | sed 's/.errors//' | tee -a errors.all
-grep -s -a -h '!     ' *.results | sed 's/.results//' | tee -a errors.all
-grep -s -a -h '*     ' *.errors | sed 's/.errors//' | tee -a errors.all
-grep -s -a -h '*     ' *.results | sed 's/.results//' | tee -a errors.all
+grep -s -a -A2 'syntax_error' -- *.results | $sed 's/.results//' | tee errors.all
+grep -s -a -A2 'syntax_error' -- *.errors | $sed 's/.errors//' | tee -a errors.all
+grep -s -a -h '!     ' -- *.errors | $sed 's/.errors//' | tee -a errors.all
+grep -s -a -h '!     ' -- *.results | $sed 's/.results//' | tee -a errors.all
+grep -s -a -h -F '*     ' -- *.errors | $sed 's/.errors//' | tee -a errors.all
+grep -s -a -h -F '*     ' -- *.results | $sed 's/.results//' | tee -a errors.all
+echo "*******************************************************************************"
+echo "***** Skipped"
+echo "*******************************************************************************"
+grep -s -a 'tests skipped' -- *.results | $sed 's/% tests skipped//' | $sed 's/.results://' | $sed 's|__|/|g' | $sed "s|^$prefix||"
+echo "*******************************************************************************"
+echo "***** Broken"
+echo "*******************************************************************************"
+grep -s -a 'LOGTALK_BROKEN' -- *.errors | $sed 's/LOGTALK_BROKEN//' | $sed 's/.errors://' | $sed 's|__|/|g' | $sed "s|^$prefix||"
 echo "*******************************************************************************"
 echo "***** Timeouts"
 echo "*******************************************************************************"
-grep -s -a 'LOGTALK_TIMEOUT' *.errors | sed 's/LOGTALK_TIMEOUT//' | sed 's/.errors://' | sed 's|__|/|g' | sed "s|^$prefix||"
+grep -s -a 'LOGTALK_TIMEOUT' -- *.errors | $sed 's/LOGTALK_TIMEOUT//' | $sed 's/.errors://' | $sed 's|__|/|g' | $sed "s|^$prefix||"
 echo "*******************************************************************************"
 echo "***** Crashes"
 echo "*******************************************************************************"
-grep -s -a 'LOGTALK_CRASH' *.errors | sed 's/LOGTALK_CRASH//' | sed 's/.errors://' | sed 's|__|/|g' | sed "s|^$prefix||"
+grep -s -a 'LOGTALK_CRASH' -- *.errors | $sed 's/LOGTALK_CRASH//' | $sed 's/.errors://' | $sed 's|__|/|g' | $sed "s|^$prefix||"
 echo "*******************************************************************************"
 echo "***** Skipped tests"
 echo "*******************************************************************************"
-grep -s -a ': skipped' *.results | sed 's/: skipped//' | sed 's/.results:% / - /' | sed 's|__|/|g' | sed "s|^$prefix||"
+grep -s -a ': skipped' -- *.results | $sed 's/: skipped//' | $sed 's/.results:% / - /' | $sed 's|__|/|g' | $sed "s|^$prefix||" | $sed "s|^% ||"
 echo "*******************************************************************************"
 echo "***** Failed tests"
 echo "*******************************************************************************"
-grep -s -a ': failure' *.results | sed 's/: failure//' | sed 's/.results:!     / - /' | sed 's|__|/|g' | sed "s|^$prefix||"
+grep -s -a ': failure' -- *.results | $sed 's/: failure//' | $sed 's/.results:!     / - /' | $sed 's|__|/|g' | $sed "s|^$prefix||" | $sed "s|^!     ||"
 echo "*******************************************************************************"
-echo "***** $testsets test sets: $testsetruns completed, $timeouts timeouts, $crashes crashes"
+echo "***** $testsets test sets: $testsetruns completed, $testsetskipped skipped, $broken broken, $timeouts timeouts, $crashes crashes"
 echo "***** $total tests: $skipped skipped, $passed passed, $failed failed"
 echo "*******************************************************************************"
 
@@ -379,8 +463,14 @@ end_date=$(eval date \"+%Y-%m-%d %H:%M:%S\")
 echo "***** Batch testing ended @ $end_date"
 echo '*******************************************************************************'
 
-if [ $failed -eq 0 ] && [ $timeouts -eq 0 ] && [ $crashes -eq 0 ] ; then
-	exit 0
-else
+if [ "$crashes" -gt 0 ] ; then
+	exit 7
+elif [ "$broken" -gt 0 ] ; then
+	exit 5
+elif [ "$timeouts" -gt 0 ] ; then
+	exit 3
+elif [ "$failed" -gt 0 ] ; then
 	exit 1
+else
+	exit 0
 fi
