@@ -3,7 +3,7 @@
 #############################################################################
 ## 
 ##   Logtalk user folder setup script
-##   Last updated on May 14, 2017
+##   Last updated on April 3, 2018
 ## 
 ##   This file is part of Logtalk <https://logtalk.org/>  
 ##   Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
@@ -25,7 +25,7 @@
 echo
 echo "This script copies all the Logtalk per-user files and directories to the"
 echo "user home directory. The location can be set by the environment variable"
-echo "\$LOGTALKUSER (defaults to \"~/logtalk\" when the variable is not defined)"
+echo "\$LOGTALKUSER (defaults to \"~/logtalk\" when the variable is not defined)."
 echo
 
 if ! [ "$LOGTALKHOME" ]; then
@@ -130,7 +130,9 @@ chmod -R u+w "$LOGTALKUSER"
 rm -f "$LOGTALKUSER"/tools/lgtdoc/xml/lgt2*
 rm -f "$LOGTALKUSER"/tools/lgtdoc/xml/logtalk.dtd
 rm -f "$LOGTALKUSER"/tools/lgtdoc/xml/logtalk.xsd
+ln -sf "$LOGTALKHOME"/ACKNOWLEDGMENTS.md "$LOGTALKUSER"/ACKNOWLEDGMENTS.md
 ln -sf "$LOGTALKHOME"/BIBLIOGRAPHY.bib "$LOGTALKUSER"/BIBLIOGRAPHY.bib
+ln -sf "$LOGTALKHOME"/CONTRIBUTING.md "$LOGTALKUSER"/CONTRIBUTING.md
 ln -sf "$LOGTALKHOME"/CUSTOMIZE.md "$LOGTALKUSER"/CUSTOMIZE.md
 ln -sf "$LOGTALKHOME"/INSTALL.md "$LOGTALKUSER"/INSTALL.md
 ln -sf "$LOGTALKHOME"/LICENSE.txt "$LOGTALKUSER"/LICENSE.txt
@@ -139,9 +141,11 @@ ln -sf "$LOGTALKHOME"/README.md "$LOGTALKUSER"/README.md
 ln -sf "$LOGTALKHOME"/RELEASE_NOTES.md "$LOGTALKUSER"/RELEASE_NOTES.md
 ln -sf "$LOGTALKHOME"/UPGRADING.md "$LOGTALKUSER"/UPGRADING.md
 ln -sf "$LOGTALKHOME"/adapters "$LOGTALKUSER"/adapters
+ln -sf "$LOGTALKHOME"/coding "$LOGTALKUSER"/coding
+ln -sf "$LOGTALKHOME"/integration "$LOGTALKUSER"/integration
 ln -sf "$LOGTALKHOME"/manuals "$LOGTALKUSER"/manuals
 ln -sf "$LOGTALKHOME"/paths "$LOGTALKUSER"/paths
-ln -sf "$LOGTALKHOME"/coding "$LOGTALKUSER"/coding
+ln -sf "$LOGTALKHOME"/scripts "$LOGTALKUSER"/scripts
 ln -sf "$LOGTALKHOME"/tools/lgtdoc/xml/lgt2html.sh "$LOGTALKUSER"/tools/lgtdoc/xml/lgt2html
 ln -sf "$LOGTALKHOME"/tools/lgtdoc/xml/lgt2pdf.sh "$LOGTALKUSER"/tools/lgtdoc/xml/lgt2pdf
 ln -sf "$LOGTALKHOME"/tools/lgtdoc/xml/lgt2xml.sh "$LOGTALKUSER"/tools/lgtdoc/xml/lgt2xml
