@@ -1,12 +1,12 @@
-#!/bin/bash
+#!/usr/bin/env bash
 
 #############################################################################
 ## 
 ##   Logtalk script for updating the HTML library and tools documentation
-##   Last updated on September 24, 2016
+##   Last updated on February 8, 2018
 ## 
-##   This file is part of Logtalk <http://logtalk.org/>  
-##   Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
+##   This file is part of Logtalk <https://logtalk.org/>  
+##   Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
 ##   
 ##   Licensed under the Apache License, Version 2.0 (the "License");
 ##   you may not use this file except in compliance with the License.
@@ -23,7 +23,7 @@
 #############################################################################
 
 
-operating_system=`uname -s`
+operating_system=$(uname -s)
 
 if [ "${operating_system:0:10}" == "MINGW32_NT" ] ; then
 	# assume that we're running on Windows using the Git for Windows bash shell
@@ -43,15 +43,17 @@ logtalk="swilgt$extension -g"
 
 
 # documentation goals
-core_goal="logtalk_load(diagrams(loader)), set_logtalk_flag(source_data,on), inheritance_diagram::library(core,[title('Logtalk core entities'),node_type_captions(true),url_prefixes('https://github.com/LogtalkDotOrg/logtalk3/tree/master/','http://logtalk.org/library/'),omit_path_prefixes(['/Users/pmoura/logtalk/','/opt/local/share/logtalk/'])]), halt."
+core_goal="logtalk_load(diagrams(loader)), set_logtalk_flag(source_data,on), inheritance_diagram::library(core,[title('Logtalk core entities'),node_type_captions(true),url_prefixes('https://github.com/LogtalkDotOrg/logtalk3/tree/master/','https://logtalk.org/library/'),omit_path_prefixes(['$LOGTALKUSER/','$LOGTALKHOME/'])]), halt."
 
-library_goal="logtalk_load(diagrams(loader)), set_logtalk_flag(source_data,on), logtalk_load(library(all_loader)), inheritance_diagram::library(library, [title('Logtalk library'),node_type_captions(true),url_prefixes('https://github.com/LogtalkDotOrg/logtalk3/tree/master/','http://logtalk.org/library/'),omit_path_prefixes(['/Users/pmoura/logtalk/','/opt/local/share/logtalk/'])]), halt."
+library_goal="logtalk_load(diagrams(loader)), set_logtalk_flag(source_data,on), logtalk_load(library(all_loader)), inheritance_diagram::library(library, [title('Logtalk library'),node_type_captions(true),url_prefixes('https://github.com/LogtalkDotOrg/logtalk3/tree/master/','https://logtalk.org/library/'),omit_path_prefixes(['$LOGTALKUSER/','$LOGTALKHOME/'])]), halt."
 
-tools_goal="logtalk_load(diagrams(loader)), set_logtalk_flag(source_data,on),logtalk_load([library(all_loader),tools(loader),ports(loader),wrapper(loader),lgtunit(tap_output),lgtunit(tap_report),lgtunit(xunit_output),lgtunit(xunit_report)]), inheritance_diagram::rlibrary(tools, [title('Logtalk development tools'),node_type_captions(true),url_prefixes('https://github.com/LogtalkDotOrg/logtalk3/tree/master/','http://logtalk.org/library/'),omit_path_prefixes(['/Users/pmoura/logtalk/','/opt/local/share/logtalk/'])]), halt."
+tools_goal="logtalk_load(diagrams(loader)), set_logtalk_flag(source_data,on),logtalk_load([library(all_loader),tools(loader),ports(loader),wrapper(loader),lgtunit(coverage_report),lgtunit(tap_output),lgtunit(tap_report),lgtunit(xunit_output),lgtunit(xunit_report)]), inheritance_diagram::rlibrary(tools, [title('Logtalk development tools'),node_type_captions(true),url_prefixes('https://github.com/LogtalkDotOrg/logtalk3/tree/master/','https://logtalk.org/library/'),omit_path_prefixes(['$LOGTALKUSER/','$LOGTALKHOME/'])]), halt."
+
+contributions_goal="logtalk_load(diagrams(loader)), set_logtalk_flag(source_data,on), logtalk_load(contributions(loader)), inheritance_diagram::rlibrary(contributions, [title('Logtalk third-party contributions'),node_type_captions(true),url_prefixes('https://github.com/LogtalkDotOrg/logtalk3/tree/master/','https://logtalk.org/library/'),omit_path_prefixes(['$LOGTALKUSER/','$LOGTALKHOME/'])]), halt."
 
 
 print_version() {
-	echo "`basename $0` 0.4"
+	echo "$(basename "$0") 0.7"
 	exit 0
 }
 
@@ -59,17 +61,18 @@ print_version() {
 usage_help()
 {
 	echo 
-	echo "This script updates the SVG diagrams of the core entities, the library, and the development tools."
+	echo "This script updates the SVG diagrams of the core entities, the library,"
+	echo "the development tools, and the third-party contributions."
 	echo
 	echo "Usage:"
-	echo "  `basename $0` [-p prolog]"
-	echo "  `basename $0` -v"
-	echo "  `basename $0` -h"
+	echo "  $(basename "$0") [-p prolog]"
+	echo "  $(basename "$0") -v"
+	echo "  $(basename "$0") -h"
 	echo
 	echo "Optional arguments:"
 	echo "  -p back-end Prolog compiler (default is $backend)"
 	echo "     (possible values are b, cx, eclipse, gnu, ji, lean, qp, sicstus, swi, xsb, xsbmt, and yap)"
-	echo "  -v print version of `basename $0`"
+	echo "  -v print version of $(basename "$0")"
 	echo "  -h help"
 	echo
 	exit 0
@@ -127,23 +130,32 @@ elif [ "$p_arg" != "" ] ; then
 	echo "Error! Unsupported back-end Prolog compiler: $p_arg"
 	usage_help
 	exit 1
-elif [ ! `command -v $backend` ] ; then
+elif [ ! "$(command -v $backend)" ] ; then
     echo "Error! Default back-end Prolog compiler not found: $prolog"
 	usage_help
     exit 1
 fi
 
 
-cd ../docs
+cd ../docs || exit 1
 
 $logtalk "$core_goal"
 $logtalk "$library_goal"
 $logtalk "$tools_goal"
+$logtalk "$contributions_goal"
 
 for f in *.dot; do
-	dot -Tsvg "$f" > "${f%.*}.svg"
+	flag=0
+	counter=10
+	while [ $flag -eq 0 ] && [ $counter -ge 0 ] ; do
+		dot -Tsvg "$f" > "${f%.*}.svg"
+		if [ $? == 0 ]; then
+			flag=1
+		fi
+		(( --counter ))
+	done
 done
 
-rm *.dot
+rm ./*.dot
 
 exit 0
